/*
 * File:        aps12c32slk.h
 * Purpose:     APS12C32SLK definitions to APSLK I/O interfaces
 *
 * Notes:
 */

#ifndef APS12C32SLK_H
#define APS12C32SLK_H

#include <mc9s12dt256.h>     /* derivative information */

/* External function prototypes */

/* On-board interfaced components */
extern void APSLK_PB_Init(void);
extern void APSLK_LED_Init(void);

/************************************************************************************************/

/* Macros define the MCU Student Learning Kit Project Board (APSLK) user I/O interfaces
   to the appropriate registers / port pins on the APS12C32SLK Application Module.
   Macros simplify the implementation of I/O interfaces in user code.
   Macros labeled with "Direct Connect" label are conveniently connected
   to the specified port pin via the APSLK and do not require jumper wire
   from MCU PORT to USER I/O header. Refer to the APSLK User Guide for
   more on this "Direct Connect" feature along with how to activate and/or
   disactivate the feature allowing the user to connect these user I/O
   interfaces to other MCU registers / port pins. Some I/O interfaces are
   left for the user to define. */
   
/* APSLK PUSH BUTTONS */
#define APSLK_PB1  PTP_PTP0          //Direct Connect
#define APSLK_PB2  PTP_PTP1			    //Direct Connect
#define APSLK_PB3  UNDEFINED		      
#define APSLK_PB4  UNDEFINED		      
#define APSLK_PB5  UNDEFINED
#define APSLK_PB6  UNDEFINED
#define APSLK_PB7  UNDEFINED
#define APSLK_PB8  UNDEFINED
#define APSLK_PBs  UNDEFINED           //Macro can be assigned to a single port for byte-wide decoding
 
/* APSLK LEDs */
#define APSLK_LED1 PORTB_BIT4          //Direct Connect          
#define APSLK_LED2 PORTB_BIT5			    //Direct Connect
#define APSLK_LED3 UNDEFINED			    
#define APSLK_LED4 UNDEFINED			    
#define APSLK_LED5 UNDEFINED
#define APSLK_LED6 UNDEFINED
#define APSLK_LED7 UNDEFINED
#define APSLK_LED8 UNDEFINED
#define APSLK_LEDs UNDEFINED           //Macro can be assigned to a single port for byte-wide decoding


/* APSLK INITIALIZATION */
#define INIT_APSLK_PBs     APSLK_PB_Init()      //Initializes pins as inputs to read PBx level
#define INIT_APSLK_LEDs    APSLK_LED_Init()     //Initializes pins as outputs to write LEDx level
//#define INIT_APSLK_POT     APSLK_POT_Init()     //Initializes ATD to sample POT value

/* Miscellaneous Macros */
#define DDRE_DDRE0_MASK 1
#define ON  0         /*Depending on Wiring Schematic..This works best for LEDs on this board*/
#define OFF 1         /*Depending on Wiring Schematic..This works best for LEDs on this board*/

/* Example use of macro definitions in user application:
   
   //Code Example
   if (!APSLK_PB1)
   {
      APSLK_LED1 = ON;
      APSLK_BUZZER_VOLUME = APSLK_POT;
   }
   else
   {
      APSLK_LED2 = ON;
      APSLK_BUZZER_TONE = APSLK_POT;
   }
   
  **Explanation of Code Example**
  If APSLK_PB1 is equal to zero, turn on APSLK_LED1. Then read the current APSLK_POT
  value sampled by ATD Ch.1 and write it to the APSLK_BUZZER_VOLUME, which sets the PWM Ch.0
  duty cycle. If APSLK_PB1 is not equal to zero, turn on APSLK_LED2 and write APSLK_POT 
  value sampled by ATD Ch. 1 and write it to the APSLK_BUZZER_TONE, which sets the PWM Ch.0
  period. */
  
#endif /* APS12C32SLK_H */